==> huaweicloudsdkaom-3.1.105-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/delete_prom_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePromInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'prom_id': 'str',
        'enterprise_project_id': 'str'
    }

    attribute_map = {
        'prom_id': 'prom_id',
        'enterprise_project_id': 'Enterprise-Project-Id'
    }

    def __init__(self, prom_id=None, enterprise_project_id=None):
        """DeletePromInstanceRequest

        The model defined in huaweicloud sdk

        :param prom_id: Prometheus实例id。
        :type prom_id: str
        :param enterprise_project_id: 企业项目id。 - 查询单个企业项目下实例，填写企业项目id。 - 查询所有企业项目下实例，填写“all_granted_eps”。
        :type enterprise_project_id: str
        """
        
        

        self._prom_id = None
        self._enterprise_project_id = None
        self.discriminator = None

        self.prom_id = prom_id
        if enterprise_project_id is not None:
            self.enterprise_project_id = enterprise_project_id

    @property
    def prom_id(self):
        """Gets the prom_id of this DeletePromInstanceRequest.

        Prometheus实例id。

        :return: The prom_id of this DeletePromInstanceRequest.
        :rtype: str
        """
        return self._prom_id

    @prom_id.setter
    def prom_id(self, prom_id):
        """Sets the prom_id of this DeletePromInstanceRequest.

        Prometheus实例id。

        :param prom_id: The prom_id of this DeletePromInstanceRequest.
        :type prom_id: str
        """
        self._prom_id = prom_id

    @property
    def enterprise_project_id(self):
        """Gets the enterprise_project_id of this DeletePromInstanceRequest.

        企业项目id。 - 查询单个企业项目下实例，填写企业项目id。 - 查询所有企业项目下实例，填写“all_granted_eps”。

        :return: The enterprise_project_id of this DeletePromInstanceRequest.
        :rtype: str
        """
        return self._enterprise_project_id

    @enterprise_project_id.setter
    def enterprise_project_id(self, enterprise_project_id):
        """Sets the enterprise_project_id of this DeletePromInstanceRequest.

        企业项目id。 - 查询单个企业项目下实例，填写企业项目id。 - 查询所有企业项目下实例，填写“all_granted_eps”。

        :param enterprise_project_id: The enterprise_project_id of this DeletePromInstanceRequest.
        :type enterprise_project_id: str
        """
        self._enterprise_project_id = enterprise_project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePromInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaom-3.1.124-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/delete_prom_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePromInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'prom_id': 'str',
        'enterprise_project_id': 'str'
    }

    attribute_map = {
        'prom_id': 'prom_id',
        'enterprise_project_id': 'Enterprise-Project-Id'
    }

    def __init__(self, prom_id=None, enterprise_project_id=None):
        """DeletePromInstanceRequest

        The model defined in huaweicloud sdk

        :param prom_id: Prometheus实例id。
        :type prom_id: str
        :param enterprise_project_id: 企业项目id。 - 删除单个企业项目下实例，填写企业项目id。
        :type enterprise_project_id: str
        """
        
        

        self._prom_id = None
        self._enterprise_project_id = None
        self.discriminator = None

        self.prom_id = prom_id
        self.enterprise_project_id = enterprise_project_id

    @property
    def prom_id(self):
        """Gets the prom_id of this DeletePromInstanceRequest.

        Prometheus实例id。

        :return: The prom_id of this DeletePromInstanceRequest.
        :rtype: str
        """
        return self._prom_id

    @prom_id.setter
    def prom_id(self, prom_id):
        """Sets the prom_id of this DeletePromInstanceRequest.

        Prometheus实例id。

        :param prom_id: The prom_id of this DeletePromInstanceRequest.
        :type prom_id: str
        """
        self._prom_id = prom_id

    @property
    def enterprise_project_id(self):
        """Gets the enterprise_project_id of this DeletePromInstanceRequest.

        企业项目id。 - 删除单个企业项目下实例，填写企业项目id。

        :return: The enterprise_project_id of this DeletePromInstanceRequest.
        :rtype: str
        """
        return self._enterprise_project_id

    @enterprise_project_id.setter
    def enterprise_project_id(self, enterprise_project_id):
        """Sets the enterprise_project_id of this DeletePromInstanceRequest.

        企业项目id。 - 删除单个企业项目下实例，填写企业项目id。

        :param enterprise_project_id: The enterprise_project_id of this DeletePromInstanceRequest.
        :type enterprise_project_id: str
        """
        self._enterprise_project_id = enterprise_project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePromInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
